@@ -1,13 +1,8 @@
-/*  $Id: cache.h 8014 2008-09-07 11:54:42Z iulius $
-**
-**  Message-ID to storage token cache.
-*/
-
 #ifndef CACHE_H
 #define CACHE_H
 
-#include "inn/libinn.h"
-#include "inn/storage.h"
+#include "libinn.h"
+#include "storage.h"
 
 BEGIN_DECLS
 
